@@ -1,10 +1,12 @@
 import yaml
 import logging
+from importlib import resources
+from . import configuration
 
 logger = logging.getLogger(__name__)
 
 def load_configuration():
-    with open('log_config.yaml', 'r') as log_file_stream:
+    with resources.path(configuration, 'log_config.yaml') as log_file_stream:
         try:
             log_config = yaml.full_load(log_file_stream)
             return log_config
